///////////////////////////////////////////////////////////////////////////////////////////////////
// lit_sphere.vert - Vertex shader for lit sphere lighting
//                   Simon Jacoby / King.com / 2012-12-05
///////////////////////////////////////////////////////////////////////////////////////////////////



// Constants (TODO: turn into uniforms)
const float g_add_mult = 0.605;                         // Tweaked by Robin in Maya
const float g_tex_scl = 0.46;                          // Tweaked by Robin in Maya
const vec4 g_add_color = vec4( 1.0, 1.0, 1.0, 1.0 );    // Tweaked by Robin in Maya



// Uniforms
///////////////////////////////////////////////////////////////////////////////////////////////////
//uniform mat4 u_modelViewMatrix;
//uniform mat4 u_viewMatrix;
uniform mat4 u_modelViewProjectionMatrix;



// Attributes
///////////////////////////////////////////////////////////////////////////////////////////////////
attribute vec4 a_position;
attribute vec3 a_normal;
attribute vec2 a_texCoord;
attribute vec4 a_color;



// Varying
///////////////////////////////////////////////////////////////////////////////////////////////////
varying vec2 v_texCoord0;
varying vec2 v_texCoord1;
varying vec4 v_color;



// Shader
///////////////////////////////////////////////////////////////////////////////////////////////////
void main() 
{
    // Transform position to clip space
    gl_Position = u_modelViewProjectionMatrix * a_position;

    // Transform normal to view space (will be used to index light texture)
//    mat3 normalTransform = mat3( u_modelViewMatrix[0].xyz,
//                                 u_modelViewMatrix[1].xyz,
//                                 u_modelViewMatrix[2].xyz );                               
//    vec3 normal = normalize( normalTransform * a_normal );

    // Fast and ugly way of bringing normal to view space, as pets will never be rotated
    vec3 normal = vec3( a_normal.x, -a_normal.y, a_normal.z );

    // Compute add color modifier (mask + color + multiplier)
    v_color = a_color.rrrr * g_add_color * g_add_mult;   // a_color.r contains mask
    
    // Copy diffuse (albedo) texcoords
    v_texCoord0 = a_texCoord;
    
    // Generate lightball texture coords from normal
	v_texCoord1 = normal.xy * g_tex_scl + 0.5;
    //v_texCoord1.y = 1.0 - v_texCoord1.y;
}
